@@ -13,7 +13,6 @@
 ##############################################################################
 """Translation Domain Views
 
-$Id: __init__.py 126935 2012-06-18 15:48:16Z tseaver $
 """
 __docformat__ = 'restructuredtext'
 
@@ -23,6 +22,9 @@ class BaseView(object):
 
     __used_for__ = ITranslationDomain
 
+    context = None
+    request = None
+
     def getAllLanguages(self):
         """Get all available languages from the Translation Domain."""
         return self.context.getAllLanguages()
