@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Placeful internationalization of content objects.
-
-$Id: interfaces.py 126935 2012-06-18 15:48:16Z tseaver $
 """
 __docformat__ = 'restructuredtext'
 
@@ -146,3 +144,10 @@ class ILocalMessageCatalog(IMessageCatalog):
     def getMessages():
         """Get a list of all the messages."""
 
+
+# Plural messages are not supported yet. Please report an issue kn
+# github in case you want to implement this feature.
+NotYetImplementedError = NotImplementedError(
+    'Plural messages are not supported yet.'
+    ' See https://github.com/zopefoundation/zope.app.i18n/issues/7'
+)
