@@ -13,59 +13,50 @@
 ##############################################################################
 """This module tests the regular persistent Translation Domain.
 
-$Id: test_translationdomain.py 128565 2012-12-10 21:53:48Z menesis $
 """
 import unittest
 import doctest
 
 from zope.component import getGlobalSiteManager
 from zope.component import provideUtility
+from zope.component import provideAdapter
 from zope.component.interfaces import IFactory
 from zope.component.factory import Factory
 from zope.i18n.interfaces import ITranslationDomain
-from zope.i18n.interfaces import IUserPreferredLanguages
-from zope.i18n.tests.test_itranslationdomain import TestITranslationDomain
+
+from zope.i18n.tests import test_itranslationdomain
 from zope.i18n.translationdomain \
      import TranslationDomain as GlobalTranslationDomain
-from zope.interface import implements
+
 from zope.interface.verify import verifyObject
 from zope.traversing.api import traverse
 
+
+from zope.app.component.testing import PlacefulSetup
+from zope.app.component.testing import createSiteManager
+
+
 from zope.app.i18n import interfaces
 from zope.app.i18n.messagecatalog import MessageCatalog
 from zope.app.i18n.translationdomain import TranslationDomain
-from zope.app.testing import setup
+
+from zope.site.site import SiteManagerAdapter
+from zope.interface.interfaces import IComponentLookup
+from zope.interface import Interface
 
 
-class Environment(object):
-
-    implements(IUserPreferredLanguages)
-
-    def __init__(self, langs=()):
-        self.langs = langs
-
-    def getPreferredLanguages(self):
-        return self.langs
+def setUpSiteManagerLookup():
+    provideAdapter(SiteManagerAdapter, (Interface,),
+                   IComponentLookup)
 
 
-class TestILocalTranslationDomain(object):
-
-    def _getTranslationDomain(self):
-        """This should be overwritten by every clas that inherits this test.
-
-           We expect the TranslationDomain to contain exactly 2 languages:
-           de and en
-        """
-
-    def setUp(self):
-        self._domain = self._getTranslationDomain()
+class AbstractTestILocalTranslationDomainMixin(object):
 
     def testInterface(self):
         verifyObject(ITranslationDomain, self._domain)
 
     def _getLanguages(self, domain):
-        languages = domain.getAllLanguages()
-        languages.sort()
+        languages = sorted(domain.getAllLanguages())
         return languages
 
     def testGetAddDeleteLanguage(self):
@@ -100,7 +91,7 @@ class TestILocalTranslationDomain(object):
 
 
 # A test mixing -- don't add this to the suite
-class TestISyncTranslationDomain(object):
+class AbstractTestISyncTranslationDomainMixin(object):
 
     foreign_messages = [
         # Message that is not locally available
@@ -133,16 +124,9 @@ class TestISyncTranslationDomain(object):
         ]
 
 
-    # This should be overwritten by every clas that inherits this test
-    def _getTranslationDomain(self):
-        pass
-
-
-    def setUp(self):
-        self._domain = self._getTranslationDomain()
-
     def testInterface(self):
         verifyObject(interfaces.ISyncTranslationDomain, self._domain)
+        super(AbstractTestISyncTranslationDomainMixin, self).testInterface()
 
     def testGetMessagesMapping(self):
         mapping = self._domain.getMessagesMapping(['de', 'en'],
@@ -177,27 +161,30 @@ class TestISyncTranslationDomain(object):
         self.assertEqual(domain.getMessage('greeting', 'de'),
                          None)
 
-                            
-class TestTranslationDomain(TestITranslationDomain,
-                            TestISyncTranslationDomain,
-                            TestILocalTranslationDomain,
-                            unittest.TestCase):
 
+class TestTranslationDomain(
+        AbstractTestISyncTranslationDomainMixin,
+        AbstractTestILocalTranslationDomainMixin,
+        test_itranslationdomain.TestITranslationDomain,
+        unittest.TestCase):
 
     def setUp(self):
-        TestITranslationDomain.setUp(self)
-
         # placefulSetup
-        setup.setUpTraversal()
-        setup.setUpSiteManagerLookup()
-        self.rootFolder = setup.buildSampleFolderTree()
+        psetup = PlacefulSetup()
+        self.sm = psetup.setUp(True, True)
+        self.rootFolder = psetup.rootFolder
 
-        self.sm = setup.createSiteManager(self.rootFolder, setsite=True)
-        setup.addUtility(self.sm, 'default', ITranslationDomain, self._domain)
+        super(TestTranslationDomain, self).setUp()
+        setUpSiteManagerLookup()
+
+        self.sm.registerUtility(self._domain, ITranslationDomain, 'default')
 
         provideUtility(Factory(MessageCatalog), IFactory,
                        'zope.app.MessageCatalog')
 
+    def tearDown(self):
+        PlacefulSetup().tearDown()
+
     def _getTranslationDomain(self):
         domain = TranslationDomain()
         domain.domain = 'default'
@@ -229,11 +216,44 @@ class TestTranslationDomain(TestITranslationDomain,
         self.assertEqual(domain['ca'].domain, domain.domain)
         domain.domain = 'default'
 
+    def test_getMessages(self):
+        messages = [{'domain': 'default',
+                     'language': 'de',
+                     'mod_time': 0,
+                     'msgid': 'greeting',
+                     'msgstr': 'Hallo $name, wie geht es Dir?'},
+                    {'domain': 'default',
+                     'language': 'de',
+                     'mod_time': 10,
+                     'msgid': 'short_greeting',
+                     'msgstr': 'Hallo!'},
+                    {'domain': 'default',
+                     'language': 'en',
+                     'mod_time': 0,
+                     'msgid': 'greeting',
+                     'msgstr': 'Hello $name, how are you?'},
+                    {'domain': 'default',
+                     'language': 'en',
+                     'mod_time': 10,
+                     'msgid': 'short_greeting',
+                     'msgstr': 'Hello!'}]
+        self.assertEqual(messages,
+                         self._domain.getMessages())
+
 class TestTranslationDomainInAction(unittest.TestCase):
 
     def setUp(self):
-        setup.placefulSetUp()
-        self.rootFolder = setup.buildSampleFolderTree()
+        psetup = PlacefulSetup()
+        self.sm = psetup.setUp(True, True)
+        self.rootFolder = psetup.rootFolder
+        setUpSiteManagerLookup()
+
+        import zope.i18n.interfaces
+        import zope.i18n.negotiator
+        provideUtility(zope.i18n.negotiator.negotiator,
+                       zope.i18n.interfaces.INegotiator)
+
+
         gsm = getGlobalSiteManager()
         de_catalog = MessageCatalog('de', 'default')
         de_catalog.setMessage('short_greeting', 'Hallo!', 10)
@@ -251,15 +271,15 @@ class TestTranslationDomainInAction(unittest.TestCase):
         de_catalog.setMessage('short_greeting', 'Hallo Welt!', 10)
         td['de-default-1'] = de_catalog
 
-        mgr = setup.createSiteManager(traverse(self.rootFolder, 'folder1'))
-        setup.addUtility(
-            mgr, 'default', interfaces.ILocalTranslationDomain, td)
+        mgr = createSiteManager(traverse(self.rootFolder, 'folder1'))
+        mgr['default']['default'] = td
+        mgr.registerUtility(mgr['default']['default'], ITranslationDomain, 'default')
 
         self.trans1 = td
         self.trans = domain
 
     def tearDown(self):
-        setup.placefulTearDown()
+        PlacefulSetup().tearDown()
 
     def test_translate(self):
         self.assertEqual(
@@ -275,13 +295,31 @@ class TestTranslationDomainInAction(unittest.TestCase):
             self.trans1.translate('long_greeting', context='default',
                                   target_language='de'),
             'Guten Tag!')
-        
+
+    def test_translate__2(self):
+        """It raises a NotImplementedError in case of plural messages."""
+        with self.assertRaises(NotImplementedError) as err:
+            self.trans1.translate('some text', msgid_plural="some texts")
+        with self.assertRaises(NotImplementedError) as err2:
+            self.trans1.translate('some text', default_plural="some texts")
+        with self.assertRaises(NotImplementedError) as err3:
+            self.trans1.translate('some text', number="some texts")
+
+        expected = (
+            'Plural messages are not supported yet.'
+            ' See https://github.com/zopefoundation/zope.app.i18n/issues/7'
+        )
+
+        self.assertEqual(str(err.exception), expected)
+        self.assertEqual(str(err2.exception), expected)
+        self.assertEqual(str(err3.exception), expected)
+
+
 def test_suite():
     return unittest.TestSuite((
-        unittest.makeSuite(TestTranslationDomain),
+        unittest.defaultTestLoader.loadTestsFromName(__name__),
         doctest.DocTestSuite('zope.app.i18n.translationdomain'),
-        unittest.makeSuite(TestTranslationDomainInAction),
-        ))
+    ))
 
-if __name__=='__main__':
+if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
