@@ -13,7 +13,6 @@
 ##############################################################################
 """This is the standard, placeful Translation Domain for TTW development.
 
-$Id: translationdomain.py 128545 2012-12-09 10:50:01Z menesis $
 """
 __docformat__ = 'restructuredtext'
 
@@ -21,7 +20,7 @@ import re
 from BTrees.OOBTree import OOBTree
 
 import zope.component
-from zope.interface import implements
+from zope.interface import implementer
 from zope.i18n import interpolate
 from zope.i18n.interfaces import INegotiator, ITranslationDomain
 from zope.i18n.simpletranslationdomain import SimpleTranslationDomain
@@ -29,10 +28,15 @@ from zope.i18n.simpletranslationdomain import SimpleTranslationDomain
 from zope.container.btree import BTreeContainer
 from zope.container.contained import Contained
 from zope.app.i18n.interfaces import ILocalTranslationDomain
+from zope.app.i18n.interfaces import NotYetImplementedError
 
+try:
+    unicode
+except NameError:
+    unicode = str
 
+@implementer(ILocalTranslationDomain)
 class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
-    implements(ILocalTranslationDomain)
 
     def __init__(self):
         super(TranslationDomain, self).__init__()
@@ -61,8 +65,12 @@ class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
         self._unregisterMessageCatalog(object.language, name)
 
     def translate(self, msgid, mapping=None, context=None,
-                  target_language=None, default=None):
+                  target_language=None, default=None, msgid_plural=None,
+                  default_plural=None, number=None):
         """See interface `ITranslationDomain`"""
+        if any((default_plural, msgid_plural, number)):
+            raise NotYetImplementedError
+
         if target_language is None and context is not None:
             avail_langs = self.getAvailableLanguages()
             # Let's negotiate the language to translate to. :)
@@ -77,6 +85,7 @@ class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
 
         for name in catalog_names:
             catalog = super(TranslationDomain, self).__getitem__(name)
+            # TODO: handle msgid_plural
             text = catalog.queryMessage(msgid)
             if text is not None:
                 break
@@ -86,10 +95,12 @@ class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
             domain = zope.component.queryNextUtility(self, ITranslationDomain,
                                                      self.domain)
             if domain is not None:
+                # TODO: handle msgid_plural
                 return domain.translate(msgid, mapping, context,
                                         target_language, default=default)
             if default is None:
                 default = unicode(msgid)
+            # TODO: handle msgid_plural/default_plural
             text = default
 
         # Now we need to do the interpolation
@@ -105,7 +116,7 @@ class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
         for language in self.getAvailableLanguages():
             for name in self._catalogs[language]:
                 for msgid in self[name].getMessageIds():
-                    if filter_re.match(msgid) >= 0:
+                    if filter_re.match(msgid):
                         msgids[msgid] = None
         return msgids.keys()
 
@@ -130,20 +141,16 @@ class TranslationDomain(BTreeContainer, SimpleTranslationDomain, Contained):
 
     def getAllLanguages(self):
         'See `IWriteTranslationDomain`'
-        languages = {}
-        for key in self._catalogs.keys():
-            languages[key] = None
-        return languages.keys()
-
+        return sorted(self._catalogs)
 
     def getAvailableLanguages(self):
         'See `IWriteTranslationDomain`'
-        return list(self._catalogs.keys())
+        return self.getAllLanguages()
 
 
     def addMessage(self, msgid, msg, language, mod_time=None):
         'See `IWriteTranslationDomain`'
-        if not self._catalogs.has_key(language):
+        if language not in self._catalogs:
             if language not in self.getAllLanguages():
                 self.addLanguage(language)
 
@@ -239,8 +246,8 @@ def setDomainOnActivation(domain, event):
     >>> domain1.domain
     '<domain not activated>'
 
-    >>> import zope.component.interfaces
-    >>> event = zope.component.interfaces.Registered(
+    >>> import zope.interface.interfaces
+    >>> event = zope.interface.interfaces.Registered(
     ...     Registration(domain1, 'domain1'))
 
     Now we pass the event into this function, and the id of the domain should
@@ -267,8 +274,8 @@ def unsetDomainOnDeactivation(domain, event):
     >>> domain1 = TranslationDomain()
     >>> domain1.domain = 'domain1'
 
-    >>> import zope.component.interfaces
-    >>> event = zope.component.interfaces.Unregistered(
+    >>> import zope.interface.interfaces
+    >>> event = zope.interface.interfaces.Unregistered(
     ...     Registration(domain1, 'domain1'))
 
     Now we pass the event into this function, and the id of the role should be
